==> nextcloud-app-contacts-3.1.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/zh_CN.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "联系人",
    "All contacts" : "全部联系人",
    "Details" : "详情",
    "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "“日历”是 Nextcloud CalDav 服务器的一个用户界面应用。通过使用此应用，您可以在不同的设备上同步您的活动并进行在线编辑。\n\n* 🚀 **集成了其他的 Nextcloud 应用！** 现在仅仅集成了联系人功能 - 将来将会集成更多。\n* 🌐 **支持WebCal！** 想要在您的日历上看到您最喜爱的球队的比赛时间？没问题！\n* 🙋 **参与人功能！** 邀请他人参与您的活动。\n* 🙈 **我们不是在做无用功！** 基于出色的 [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) 和 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 库开发.",
    "Copy to full name" : "复制到全名",
    "Omit year" : "忽略年份",
    "Add new property" : "新增属性",
    "Choose property type" : "选择属性类型",
    "Add a new picture" : "添加一张新图片",
    "Upload a new picture" : "上传一张新的图片",
    "Choose from files" : "从文件中选择",
    "Delete picture" : "删除图片",
    "Download picture" : "下载图片",
    "Image is too big (max 1MB)." : "图片过大(最大1MB)",
    "Pick an avatar" : "选择一个头像",
    "Error while processing the picture." : "处理图片时出错。",
    "No contact selected" : "请选择联系人",
    "Select a contact on the list to begin" : "请先在列表里选择联系人",
    "Loading" : "载入中",
    "Name" : "名称",
    "Company" : "公司",
    "Title" : "头衔",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人已损坏但接收到了一个修复。请查看内容并点击这里以保存它。",
    "Download" : "下载",
    "Generate QR Code" : "生成二维码",
    "Delete" : "删除",
    "This contact is not yet synced. Edit it to save it to the server." : "此联系人尚未同步。 编辑它以将其保存到服务器。",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
    "Addressbook" : "地址簿",
    "Groups" : "群组",
    "New contact" : "新建联系人",
    "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
    "Deleting the contact in {countdown} seconds" : "正在删除联系人, 剩余 {countdown} 秒",
    "Done importing {total} contacts into" : "导入 {total} 个联系人",
    "Importing {total} contacts into" : "导入 {total} 个联系人",
    "No errors" : "没有错误",
    "Open your browser console for more details" : "打开浏览器控制台以获取更多详细信息",
    "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} 个有错误的联系人"],
    "Select type" : "选择类型",
    "Select Date" : "选择日期",
    "Add contact in group" : "添加联系人到群组",
    "No results" : "无结果",
    "Last modified" : "上一次更改",
    "Select option" : "选择选项",
    "Rename" : "重命名",
    "Enabled" : "已启用",
    "Disabled" : "已禁用",
    "Copied" : "已复制",
    "Can not copy" : "无法复制",
    "Copy link" : "复制链接",
    "Enabled toggle of addressbook was not successful." : "启用切换地址簿未成功。",
    "This will delete the addressbook and every contacts within it" : "这将删除地址簿及其中所有联系人",
    "Delete {addressbook} ?" : "删除 {addressbook} ？",
    "Deletion of addressbook was not successful." : "未能成功删除地址簿。",
    "Renaming of addressbook was not successful." : "未能成功重命名地址簿。",
    "Addressbook copied to clipboard" : "已复制地址簿到剪切板。",
    "Addressbook was not copied to clipboard." : "地址簿不能成功的复制到剪切板。",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
    "Share with users or groups" : "和用户或者组群共享",
    "No users or groups" : "无用户或群组",
    "can edit" : "可编辑",
    "Unable to delete the share." : "无法删除此共享。",
    "Unable to change permissions." : "无法修改权限。",
    "Importing into" : "导入到",
    "Import into" : "导入到",
    "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
    "Address book name" : "地址簿名称",
    "An error occurred, unable to create the addressbook." : "发生了错误，地址簿未能成功创建。",
    "First name" : "名",
    "Last name" : "姓",
    "Display name" : "显示名称",
    "Sort by {sorting}" : "以 {sorting} 排序",
    "Not grouped" : "未分组",
    "Unable to create the contact." : "未能成功创建联系人。",
    "Contact not found" : "未找到联系人",
    "Nickname" : "昵称",
    "Detailed name" : "全名",
    "Additional names" : "其他名称",
    "Prefix" : "前缀",
    "Suffix" : "后缀",
    "Notes" : "说明",
    "Website" : "网站",
    "Location" : "地点",
    "Federated Cloud ID" : "联合云 ID",
    "Home" : "家庭",
    "Work" : "工作",
    "Other" : "其它",
    "Address" : "地址",
    "Post office box" : "邮政信箱",
    "Extended address" : "附加地址",
    "City" : "城市",
    "State or province" : "州/省",
    "Postal code" : "邮政编码",
    "Country" : "国家",
    "Birthday" : "生日",
    "Anniversary" : "周年",
    "The date of marriage, or equivalent, of this contact" : "此联系人的结婚纪念日，或与之相当的日期",
    "Date of death" : "去世日期",
    "Email" : "电子邮件",
    "Instant messaging" : "即时通讯",
    "Phone" : "电话",
    "Mobile" : "手机",
    "Work mobile" : "工作电话",
    "Home mobile" : "家庭移动电话",
    "Fax" : "传真",
    "Fax home" : "家庭传真",
    "Fax work" : "工作传真",
    "Pager" : "传呼机",
    "Voice" : "语音",
    "Car" : "车",
    "Work pager" : "工作传呼机",
    "Social network" : "社交网络",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "个人资料网址。例如https://www.facebook.com/NextClouders/",
    "Relationship" : "关系",
    "Specify a relationship between you and the entity represented by this vCard." : "请描述您和这张 vCard 上人员的关系",
    "Spouse" : "配偶",
    "Child" : "子女",
    "Mother" : "母亲",
    "Father" : "父亲",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姐妹",
    "Relative" : "关系",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Manager" : "经理",
    "Assistant" : "助理",
    "Related" : "相关",
    "Specify a relationship between another entity and the entity represented by this vCard." : "请描述您和这张 vCard 上人员的关系。",
    "Contact" : "联系",
    "Agent" : "代理",
    "Emergency" : "紧急",
    "Co-worker" : "同事",
    "Gender" : "性别",
    "Female" : "女性",
    "Male" : "男性",
    "None" : "无",
    "Unknown" : "未知",
    "Timezone" : "时区",
    "Spoken languages" : "口语",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 联系人读取失败"],
    "An error occurred" : "发生错误",
    "Your web browser is out of date" : "您的浏览器版本太旧",
    "This application is not compatible with Internet Explorer" : "此应用与Internet Explorer不兼容"
},
"nplurals=1; plural=0;");

==> nextcloud-app-contacts-3.1.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/zh_CN.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "联系人",
    "All contacts" : "全部联系人",
    "Details" : "详情",
    "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "“日历”是 Nextcloud CalDav 服务器的一个用户界面应用。通过使用此应用，您可以在不同的设备上同步您的活动并进行在线编辑。\n\n* 🚀 **集成了其他的 Nextcloud 应用！** 现在仅仅集成了联系人功能 - 将来将会集成更多。\n* 🌐 **支持WebCal！** 想要在您的日历上看到您最喜爱的球队的比赛时间？没问题！\n* 🙋 **参与人功能！** 邀请他人参与您的活动。\n* 🙈 **我们不是在做无用功！** 基于出色的 [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) 和 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 库开发.",
    "Copy to full name" : "复制到全名",
    "Omit year" : "忽略年份",
    "Add new property" : "新增属性",
    "Choose property type" : "选择属性类型",
    "Add a new picture" : "添加一张新图片",
    "Upload a new picture" : "上传一张新的图片",
    "Choose from files" : "从文件中选择",
    "Delete picture" : "删除图片",
    "Download picture" : "下载图片",
    "Image is too big (max 1MB)." : "图片过大(最大1MB)",
    "Pick an avatar" : "选择一个头像",
    "Error while processing the picture." : "处理图片时出错。",
    "No contact selected" : "请选择联系人",
    "Select a contact on the list to begin" : "请先在列表里选择联系人",
    "Loading" : "正在加载",
    "Name" : "名称",
    "Company" : "公司",
    "Title" : "头衔",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人已损坏但接收到了一个修复。请查看内容并点击这里以保存它。",
    "Download" : "下载",
    "Generate QR Code" : "生成二维码",
    "Delete" : "删除",
    "This contact is not yet synced. Edit it to save it to the server." : "此联系人尚未同步。 编辑它以将其保存到服务器。",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
    "Addressbook" : "地址簿",
    "Groups" : "群组",
    "New contact" : "新建联系人",
    "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
    "Deleting the contact in {countdown} seconds" : "正在删除联系人, 剩余 {countdown} 秒",
    "Done importing {total} contacts into" : "导入 {total} 个联系人",
    "Importing {total} contacts into" : "正在导入 {total} 个联系人",
    "No errors" : "没有错误",
    "Open your browser console for more details" : "打开浏览器控制台以获取更多详细信息",
    "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} 个有错误的联系人"],
    "Select type" : "选择类型",
    "Select Date" : "选择日期",
    "Add contact in group" : "添加联系人到群组",
    "No results" : "无结果",
    "Last modified" : "上一次更改",
    "Select option" : "选择选项",
    "Rename" : "重命名",
    "Enabled" : "已启用",
    "Disabled" : "已禁用",
    "Copied" : "已复制",
    "Can not copy" : "无法复制",
    "Copy link" : "复制链接",
    "Enabled toggle of addressbook was not successful." : "启用切换地址簿未成功。",
    "This will delete the addressbook and every contacts within it" : "这将删除地址簿及其中所有联系人",
    "Delete {addressbook} ?" : "删除 {addressbook} ？",
    "Deletion of addressbook was not successful." : "未能成功删除地址簿。",
    "Renaming of addressbook was not successful." : "未能成功重命名地址簿。",
    "Addressbook copied to clipboard" : "地址簿已复制到剪贴板。",
    "Addressbook was not copied to clipboard." : "地址簿未复制到剪贴板。",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
    "Share with users or groups" : "和用户或者组群共享",
    "No users or groups" : "无用户或群组",
    "can edit" : "可编辑",
    "Unable to delete the share." : "无法删除此共享。",
    "Unable to change permissions." : "无法修改权限。",
    "Importing into" : "导入到",
    "Import into" : "导入到",
    "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
    "Address book name" : "地址簿名称",
    "An error occurred, unable to create the addressbook." : "发生了错误，地址簿未能成功创建。",
    "First name" : "名",
    "Last name" : "姓",
    "Display name" : "显示名称",
    "Sort by {sorting}" : "以 {sorting} 排序",
    "Not grouped" : "未分组",
    "Unable to create the contact." : "未能成功创建联系人。",
    "Contact not found" : "未找到联系人",
    "Nickname" : "昵称",
    "Detailed name" : "全名",
    "Additional names" : "其他名称",
    "Prefix" : "前缀",
    "Suffix" : "后缀",
    "Notes" : "说明",
    "Website" : "网站",
    "Location" : "地点",
    "Federated Cloud ID" : "联合云 ID",
    "Home" : "家庭",
    "Work" : "工作",
    "Other" : "其它",
    "Address" : "地址",
    "Post office box" : "邮政信箱",
    "Extended address" : "附加地址",
    "City" : "城市",
    "State or province" : "州/省",
    "Postal code" : "邮政编码",
    "Country" : "国家",
    "Birthday" : "生日",
    "Anniversary" : "周年",
    "The date of marriage, or equivalent, of this contact" : "此联系人的结婚纪念日，或与之相当的日期",
    "Date of death" : "去世日期",
    "Email" : "电子邮件",
    "Instant messaging" : "即时通讯",
    "Phone" : "电话",
    "Mobile" : "手机",
    "Work mobile" : "工作电话",
    "Home mobile" : "家庭移动电话",
    "Fax" : "传真",
    "Fax home" : "家庭传真",
    "Fax work" : "工作传真",
    "Pager" : "传呼机",
    "Voice" : "语音",
    "Car" : "车",
    "Work pager" : "工作传呼机",
    "Social network" : "社交网络",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "个人资料网址。例如https://www.facebook.com/NextClouders/",
    "Relationship" : "关系",
    "Specify a relationship between you and the entity represented by this vCard." : "请描述您和这张 vCard 上人员的关系",
    "Spouse" : "配偶",
    "Child" : "子女",
    "Mother" : "母亲",
    "Father" : "父亲",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姐妹",
    "Relative" : "关系",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Manager" : "经理",
    "Assistant" : "助理",
    "Related" : "相关",
    "Specify a relationship between another entity and the entity represented by this vCard." : "请描述您和这张 vCard 上人员的关系。",
    "Contact" : "联系",
    "Agent" : "代理",
    "Emergency" : "紧急",
    "Co-worker" : "同事",
    "Gender" : "性别",
    "Female" : "女性",
    "Male" : "男性",
    "None" : "无",
    "Unknown" : "未知",
    "Timezone" : "时区",
    "Spoken languages" : "口语",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
    "An error occurred" : "发生错误",
    "Your web browser is out of date" : "您的浏览器版本太旧",
    "This application is not compatible with Internet Explorer" : "此应用与Internet Explorer不兼容"
},
"nplurals=1; plural=0;");
